Class: MailerLog::Current
- Inherits:
-
ActiveSupport::CurrentAttributes
- Object
- ActiveSupport::CurrentAttributes
- MailerLog::Current
- Defined in:
- app/models/mailer_log/current.rb
Overview
Thread-safe storage for passing data between interceptor and observer. Uses ActiveSupport::CurrentAttributes which automatically resets between requests and is safe for multi-threaded servers.